@@ -236,6 +236,7 @@ class OWSConfigEntry:
 # Label names for metadata separation and translation
 
 FLD_TITLE = "title"
+FLD_UNITS = "units"
 FLD_ABSTRACT = "abstract"
 FLD_KEYWORDS = "local_keywords"
 FLD_FEES = "fees"
@@ -261,6 +262,9 @@ class OWSMetadataConfig(OWSConfigEntry):
     METADATA_ACCESS_CONSTRAINTS: bool = False
     METADATA_ATTRIBUTION: bool = False
     METADATA_DEFAULT_BANDS: bool = False
+    METADATA_VALUE_RULES: bool = False
+    METADATA_LEGEND_UNITS: bool = False
+    METADATA_TICK_LABELS: bool = False
 
     # Class registries, mapping metadata paths to their default value and whether the metadata value is
     # unique to that path, or has been inherited from a parent metadata path.
@@ -287,8 +291,13 @@ class OWSMetadataConfig(OWSConfigEntry):
         return None
 
     # Holders for managing inheritance.
-    default_title: Optional[str] = None
-    default_abstract: Optional[str] = None
+    @property
+    def default_title(self) -> Optional[str]:
+        return None
+
+    @property
+    def default_abstract(self) -> Optional[str]:
+        return None
 
     _keywords: Set[str] = set()
 
@@ -303,11 +312,11 @@ class OWSMetadataConfig(OWSConfigEntry):
         # pylint: disable=assignment-from-none
         inherit_from = self.can_inherit_from()
         if self.METADATA_TITLE:
-            if self.default_title:
-                self.register_metadata(self.get_obj_label(), FLD_TITLE, cast(str, cfg.get("title", self.default_title)))
+            if self.default_title is not None:
+                self.register_metadata(self.get_obj_label(), FLD_TITLE, cast(str, cfg.get(FLD_TITLE, self.default_title)))
             else:
                 try:
-                    self.register_metadata(self.get_obj_label(), FLD_TITLE, cast(str, cfg["title"]))
+                    self.register_metadata(self.get_obj_label(), FLD_TITLE, cast(str, cfg[FLD_TITLE]))
                 except KeyError:
                     raise ConfigException(f"Entity {self.get_obj_label()} has no title.")
         if self.METADATA_ABSTRACT:
@@ -341,7 +350,7 @@ class OWSMetadataConfig(OWSConfigEntry):
             if attrib_title:
                 self.register_metadata(self.get_obj_label(), FLD_ATTRIBUTION, attrib_title, inheriting)
         if self.METADATA_FEES:
-            fees = cast(str, cfg.get("fees"))
+            fees = cast(str, cfg.get(FLD_FEES))
             if not fees:
                 fees = "none"
             self.register_metadata(self.get_obj_label(), FLD_FEES, fees)
@@ -365,6 +374,19 @@ class OWSMetadataConfig(OWSConfigEntry):
                     self.register_metadata(self.get_obj_label(), k, v[0])
                 else:
                     self.register_metadata(self.get_obj_label(), k, k)
+        if self.METADATA_VALUE_RULES:
+            # Note that parse_metadata must be called after the value map is parsed.
+            for patch in self.patches:
+                self.register_metadata(self.get_obj_label(), f"rule_{patch.idx}", patch.label)
+        if self.METADATA_LEGEND_UNITS:
+            units = cast(str, cfg.get(FLD_UNITS))
+            if units is not None:
+                self.register_metadata(self.get_obj_label(), FLD_UNITS, units)
+        if self.METADATA_TICK_LABELS:
+            # Note that parse_metadata must be called after legend ticks are parsed.
+            for tick, lbl in zip(self.ticks, self.tick_labels):
+                if any(c.isalpha() for c in lbl):
+                    self.register_metadata(self.get_obj_label(), f"lbl_{tick}", lbl)
 
     @property
     def keywords(self) -> Set[str]:
@@ -468,7 +490,9 @@ class OWSMetadataConfig(OWSConfigEntry):
         """"
         Expose separated or internationalised metadata as attributes
         """
-        if name in (FLD_TITLE, FLD_ABSTRACT, FLD_FEES, FLD_ACCESS_CONSTRAINTS, FLD_CONTACT_POSITION, FLD_CONTACT_ORGANISATION):
+        if name in (FLD_TITLE, FLD_ABSTRACT, FLD_FEES,
+                    FLD_ACCESS_CONSTRAINTS, FLD_CONTACT_POSITION, FLD_CONTACT_ORGANISATION,
+                    FLD_UNITS):
             return self.read_local_metadata(name)
         elif name == FLD_KEYWORDS:
             kw = self.read_local_metadata(FLD_KEYWORDS)
