@@ -135,7 +135,7 @@ class DataStacker:
         elif bands:
             self._needed_bands = [self._product.band_idx.locale_band(b) for b in bands]
         else:
-            self._needed_bands = list(self._product.band_idx.native_bands.index)
+            self._needed_bands = list(self._product.band_idx.measurements.keys())
 
         for band in self._product.always_fetch_bands:
             if band not in self._needed_bands:
@@ -303,16 +303,16 @@ class DataStacker:
             for ds in tds.values.item():
                 d = self.read_data_for_single_dataset(ds, measurements, self._geobox, fuse_func=fuse_func)
                 # Squeeze upconverts uints to int32
-                d = d.squeeze(["time"], drop=True)
+                dm = d.squeeze(["time"], drop=True)
                 extent_mask = None
                 for band in non_flag_bands:
                     for f in self._product.extent_mask_func:
                         if extent_mask is None:
-                            extent_mask = f(d, band)
+                            extent_mask = f(dm, band)
                         else:
-                            extent_mask &= f(d, band)
+                            extent_mask &= f(dm, band)
                 if extent_mask is not None:
-                    dm = d.where(extent_mask)
+                    dm = dm.where(extent_mask)
                 if self._product.solar_correction and not skip_corrections:
                     for band in non_flag_bands:
                         dm[band] = solar_correct_data(dm[band], ds)
