@@ -38,10 +38,11 @@ from datacube_ows.ogc_utils import (ConfigException, FunctionWrapper,
                                     create_geobox, day_summary_date_range,
                                     local_solar_date_range, month_date_range,
                                     year_date_range)
-from datacube_ows.resource_limits import OWSResourceManagementRules
+from datacube_ows.resource_limits import (OWSResourceManagementRules,
+                                          parse_cache_age)
 from datacube_ows.styles import StyleDef
 from datacube_ows.tile_matrix_sets import TileMatrixSet
-from datacube_ows.utils import group_by_statistical
+from datacube_ows.utils import group_by_solar, group_by_statistical
 
 _LOG = logging.getLogger(__name__)
 
@@ -84,8 +85,9 @@ class BandIndex(OWSMetadataConfig):
         self.parse_metadata(band_cfg)
         self._idx = {}
         self.add_aliases(self.band_cfg)
-        self.declare_unready("native_bands")
         self.declare_unready("_nodata_vals")
+        self.declare_unready("measurements")
+        self.declare_unready("_dtypes")
 
     def global_config(self):
         return self.product.global_config()
@@ -104,22 +106,42 @@ class BandIndex(OWSMetadataConfig):
                 self._idx[a] = b
 
     def make_ready(self, dc, *args, **kwargs):
+        def floatify_nans(inp):
+            if isinstance(inp, str) and inp == "nan":
+                return float(inp)
+            else:
+                return inp
+        default_to_all = not bool(self._raw_cfg)
         # pylint: disable=attribute-defined-outside-init
-        self.native_bands = dc.list_measurements().loc[self.product.product_name]
-        if not self._raw_cfg:
-            for b in self.native_bands.index:
-                self.band_cfg[b] = []
-            self.add_aliases(self.band_cfg)
-        # pylint: disable=attribute-defined-outside-init
+        self.measurements = {}
         self._nodata_vals = {}
         self._dtypes = {}
-        for b, aliases in self.band_cfg.items():
-            if b not in self.native_bands.index:
-                raise ConfigException(f"Unknown band: {b} in layer {self.product.name}")
-            self._nodata_vals[b] = self.native_bands['nodata'][b]
-            self._dtypes[b] = numpy.dtype(self.native_bands.dtype[b])
-            if isinstance(self._nodata_vals[b], str) and self._nodata_vals[b].lower() == "nan":
-                self._nodata_vals[b] = float("nan")
+        first_product = True
+        for product in self.product.products:
+            if first_product and default_to_all:
+                native_bands = dc.list_measurements().loc[product.name]
+                for b in native_bands.index:
+                    self.band_cfg[b] = [b]
+                self.add_aliases(self.band_cfg)
+            try:
+                prod_measurements = product.lookup_measurements(list(self.band_cfg.keys()))
+                if first_product:
+                    self.measurements = prod_measurements
+                    self._nodata_vals = {name: floatify_nans(model.nodata) for name, model in self.measurements.items()}
+                    self._dtypes = {name: numpy.dtype(model.dtype) for name, model in self.measurements.items()}
+                else:
+                    for k in prod_measurements:
+                        nodata = self._nodata_vals[k]
+                        if ((numpy.isnan(nodata) and not numpy.isnan(floatify_nans(prod_measurements[k].nodata)))
+                                or (not numpy.isnan(nodata) and prod_measurements[k].nodata != nodata)):
+                            raise ConfigException(
+                                f"Nodata value mismatch between products for band {k} in multiproduct layer {self.product.name}")
+                        if prod_measurements[k].dtype != self._dtypes[k]:
+                            raise ConfigException(
+                                f"Data type mismatch between products for band {k} in multiproduct layer {self.product.name}")
+            except KeyError as e:
+                raise ConfigException(f"Product {product.name} in layer {self.product.name} is missing band {e}")
+            first_product = False
         super().make_ready(dc, *args, **kwargs)
 
     def band(self, name_alias):
@@ -395,7 +417,7 @@ class OWSNamedLayer(OWSExtensibleConfigEntry, OWSLayer):
         self.cfg_native_crs = cfg.get("native_crs")
         self.declare_unready("resolution_x")
         self.declare_unready("resolution_y")
-        self.resource_limits = OWSResourceManagementRules(cfg.get("resource_limits", {}), f"Layer {self.name}")
+        self.resource_limits = OWSResourceManagementRules(self.global_cfg, cfg.get("resource_limits", {}), f"Layer {self.name}")
         try:
             self.parse_flags(cfg.get("flags", {}))
             self.declare_unready("all_flag_band_names")
@@ -498,8 +520,8 @@ class OWSNamedLayer(OWSExtensibleConfigEntry, OWSLayer):
         self.data_manual_merge = cfg.get("manual_merge", False)
         if self.solar_correction and not self.data_manual_merge:
             raise ConfigException("Solar correction requires manual_merge.")
-        if self.data_manual_merge and not self.solar_correction:
-            _LOG.warning("Manual merge is only recommended where solar correction is required.")
+        if self.data_manual_merge and not self.solar_correction and not self.multi_product:
+            _LOG.warning("Manual merge is only recommended where solar correction is required and for multi-product layers.")
 
         if cfg.get("fuse_func"):
             self.fuse_func = FunctionWrapper(self, cfg["fuse_func"])
@@ -560,11 +582,14 @@ class OWSNamedLayer(OWSExtensibleConfigEntry, OWSLayer):
 
     # pylint: disable=attribute-defined-outside-init
     def parse_wcs(self, cfg):
-        if not self.global_cfg.wcs:
+        if cfg == False:
+            self.wcs = False
+        elif not self.global_cfg.wcs:
             self.wcs = False
-            return
         else:
-            self.wcs = True
+            self.wcs = not cfg.get("disable", False)
+        if not self.wcs:
+            return
 
         if "native_resolution" in cfg:
             if not self.cfg_native_resolution:
@@ -948,6 +973,12 @@ class OWSMultiProductLayer(OWSNamedLayer):
             "pq_low_res_names": pq_low_res_names,
         }
 
+    def dataset_groupby(self):
+        if self.is_raw_time_res:
+            return group_by_solar(self.product_names)
+        else:
+            return group_by_statistical(self.product_names)
+
 
 def parse_ows_layer(cfg, global_cfg, parent_layer=None, sibling=0):
     if cfg.get("name", None):
@@ -1076,6 +1107,14 @@ class OWSConfig(OWSMetadataConfig):
     def default_abstract(self) -> Optional[str]:
         return ""
 
+    @property
+    def active_products(self):
+        return filter(lambda x: not x.hide, self.product_index.values())
+
+    @property
+    def active_product_index(self):
+        return {prod.name: prod for prod in self.active_products}
+
     def __init__(self, refresh=False, cfg=None, ignore_msgfile=False, called_from_update_ranges=False):
         self.called_from_update_ranges = called_from_update_ranges
         if not self.initialised or refresh:
@@ -1249,10 +1288,20 @@ class OWSConfig(OWSMetadataConfig):
         self.s3_bucket = cfg.get("s3_bucket", "")
         self.s3_url = cfg.get("s3_url", "")
         self.s3_aws_zone = cfg.get("s3_aws_zone", "")
-        self.wms_max_width = cfg.get("max_width", 256)
-        self.wms_max_height = cfg.get("max_height", 256)
+        try:
+            self.wms_max_width = int(cfg.get("max_width", 256))
+            self.wms_max_height = int(cfg.get("max_height", 256))
+        except ValueError:
+            raise ConfigException(
+                f"max_width and max_height in wms section must be integers: {cfg.get('max_width', 256)},{cfg.get('max_height', 256)}"
+            )
+        if self.wms_max_width < 1 or self.wms_max_height < 1:
+            raise ConfigException(
+                f"max_width and max_height in wms section must be positive integers: {cfg.get('max_width', 256)},{cfg.get('max_height', 256)}"
+            )
         self.authorities = cfg.get("authorities", {})
         self.user_band_math_extension = cfg.get("user_band_math_extension", False)
+        self.wms_cap_cache_age = parse_cache_age(cfg, "caps_cache_maxage", "wms")
         if "attribution" in cfg:
             _LOG.warning("Attribution entry in top level 'wms' section will be ignored. Attribution should be moved to the 'global' section")
 
@@ -1276,12 +1325,16 @@ class OWSConfig(OWSMetadataConfig):
             if self.native_wcs_format not in self.wcs_formats_by_name:
                 raise ConfigException(f"Configured native WCS format ({self.native_wcs_format}) not a supported format.")
             self.wcs_tiff_statistics = cfg.get("calculate_tiff_statistics", True)
+            self.wcs_cap_cache_age = parse_cache_age(cfg, "caps_cache_maxage", "wcs")
+            self.wcs_default_descov_age = parse_cache_age(cfg, "default_desc_cache_maxage", "wcs")
         else:
             self.wcs_formats = []
             self.wcs_formats_by_name = {}
             self.wcs_formats_by_mime = {}
             self.native_wcs_format = None
             self.wcs_tiff_statistics = False
+            self.wcs_cap_cache_age = 0
+            self.wcs_default_descov_age = 0
 
     def parse_wmts(self, cfg):
         tms_cfgs = TileMatrixSet.default_tm_sets.copy()
