@@ -6,7 +6,22 @@ import numpy as np
 from datacube.utils.geometry import CRS, GeoBox, polygon
 
 from datacube_ows.config_utils import CFG_DICT, RAW_CFG, OWSConfigEntry
-from datacube_ows.ogc_utils import ConfigException, create_geobox
+from datacube_ows.ogc_utils import (ConfigException, cache_control_headers,
+                                    create_geobox)
+
+
+def parse_cache_age(cfg, entry, section, default=0):
+    try:
+        val = int(cfg.get(entry, default))
+    except ValueError:
+        raise ConfigException(
+            f"{entry} in {section} section must be an integer: {cfg[entry]}"
+        )
+    if val < 0:
+        raise ConfigException(
+            f"{entry} in {section} section cannot be negative: {cfg[entry]}"
+        )
+    return val
 
 
 # pyre-ignore[13]
@@ -163,16 +178,16 @@ class CacheControlRules(OWSConfigEntry):
             return {}
         assert n_datasets >= 0
         if n_datasets == 0 or n_datasets > self.max_datasets:
-            return {"cache-control": "no-cache"}
+            return cache_control_headers(0)
         rule = None
         for r in self.rules:
             if n_datasets < r["min_datasets"]:
                 break
             rule = r
         if rule:
-            return {"cache-control": f"max-age={rule['max_age']}"}
+            return cache_control_headers(rule['max_age'])
         else:
-            return {"cache-control": "no-cache"}
+            return cache_control_headers(0)
 
 
 class ResourceLimited(Exception):
@@ -184,7 +199,11 @@ class ResourceLimited(Exception):
 
 class OWSResourceManagementRules(OWSConfigEntry):
     # pylint: disable=attribute-defined-outside-init
-    def __init__(self, cfg: CFG_DICT, context: str) -> None:
+    def __init__(self,
+                 global_cfg: "datacube_ows.ows_configuration.OWSConfig",
+                 cfg: CFG_DICT,
+                 context: str
+                 ) -> None:
         """
         Class constructor.
 
@@ -207,6 +226,12 @@ class OWSResourceManagementRules(OWSConfigEntry):
         self.max_image_size_wcs = cast(int, wcs_cfg.get("max_image_size", 0))
         self.wms_cache_rules = CacheControlRules(wms_cfg.get("dataset_cache_rules"), context, self.max_datasets_wms)
         self.wcs_cache_rules = CacheControlRules(wcs_cfg.get("dataset_cache_rules"), context, self.max_datasets_wcs)
+        self.wcs_desc_cache_rule = parse_cache_age(
+            cfg,
+            "describe_cache_max_age",
+            f"resource_limits for {context}",
+            default=global_cfg.wcs_default_descov_age
+        )
 
     def check_wms(self, n_datasets: int, zoom_factor: float, request_scale: RequestScale) -> None:
         """
